******************************************************************************************
******************************************************************************************
**** Code files for "How Elastic Are Preferences for Redistribution:                 *****
**** Evidence from Randomized Survey Experiments."                                   *****                  
******************************************************************************************
*** Authors: Ilyana Kuziemko, Michael Norton, Emmanuel Saez and Stefanie Stantcheva  *****
*** Date: November 2014                                                              *****
*** For questions and comments please contact Stefanie Stantcheva                    *****
*** sstantcheva@fas.harvard.edu                                                      *****
******************************************************************************************
******************************************************************************************

******************************************************************************************
******* Omnibus Treatment                             
******************************************************************************************
******* input: Inequality_AER_Omnibus.dta, data from the large omnibus experiment
******* alp_nowgt.ster for estimates from the ALP sample (provided by Ray Fisman), 
******* cbs_2011.dta, for statistics from the CBS.
******* output: main paper and appendix tables for all omnibus results
******************************************************************************************


* Modify the path here to the folder where you placed the datasets

* Please check the variable labels and value labels, which show the survey question asked
* and the answer choices given to respondents.


cd "/Users/stefaniestantcheva/Dropbox/inequality/AER_revision2/data/"

clear
set mem 500m
set more off

cap log close
log using ineq_omnibus.log, replace

******************************************************************************************
******* Omnibus Treatment                                        
******************************************************************************************

use Inequality_AER_Omnibus.dta, clear

* this data contains the 4 rounds during which the omnibus experiment data was collected. 
* the waves are recorded in the variable "rounds"
* round == 6 (round 1) Conducted on mTurk
* round == 7 (round 2) Conducted on mTurk
* round == 7.1 (round 3) Conducted with CT Marketing group
* round ==  8 (round 4) Conducted on mTurk
	  
drop if age<18 

* Treat definition 1: everyone not in control group
gen treat=.
replace treat=1 if (group == "Treatment Group" & round != 8) 
replace treat=1 if round==8 & (group=="Treatment Group" | group=="FL_64" | group=="Treatment Group 2")

replace treat=0 if group == "Control"
tab treat group

******************************************************************************************
********* Definition of background variables 
******************************************************************************************

gen temp=party2008==1 if party2008~=.
replace obama08=temp if obama08==.

gen male=gender==1 if gender~=.
gen native=usborn==1 if usborn~=.
gen married=marital==2 if marital~=.
gen white=ethnic==1 if ethnic~=.
gen black=ethnic==2 if ethnic~=.
gen hisp=ethnic==3 if ethnic~=.
gen asian=ethnic==4 if ethnic~=.
gen college=educ>5 if educ~=.
gen fulltime=employ==1 if employ~=.
gen unemp=employ==4 if employ~=.
gen student=employ==5 if employ~=.
gen nilf=employ==6 if employ~=.
qui tab round, gen(rrr)
qui tab hhincome, missing gen(hhh) 
gen poor=hhincome<4 if hhincome~=.
gen liberal=policyview>3 if policyview~=. 
gen conservative = policyview<=2 if policyview~=. 
tab ethnic, gen(eee)

****Create 3-category policyview to compare with polling data
gen policyview3=1 if policyview<3
replace policyview3=2 if policyview==3
replace policyview3=3 if policyview>3 & policyview~=.

******************************************************************************************
********* Definition of outcome variables 
******************************************************************************************

* Binary variable equal to 1 if respondent says should increase tax on millionaires: 
gen inc_mill_yes=tax_mill==1 if tax_mill~=.
* Binary variable equal to 1 if respondent says should increase estate tax: 
gen inc_estate_yes=estate_tax==3 if estate_tax~=.
* Vote for democrat or republican in 2014
gen democrat12=(party2012==1) if party2012~=.
gen republican12 = (party2012 == 2) if party2012~=.

* Generate outcomes increasing in the amount of support for each policy:
gen inc_mw=minwage==3 if minwage~=. 
gen support_eitc=eitc==1 if eitc~=.
gen support_food=foodst==1 if foodst~=.

****Flip a few around so that they are increasing instead of decreasing
replace trust_gov=5-trust_gov
*Now, 1 = hardly ever trust, 4 = just about always

replace satisfied=5-satisfied
replace deserving=4-deserving

* Binary outcome "Inequality has increased"
gen ineq_inc_yes=inequality_increase==3 if inequality_increase~=.

* Binary outcome 'Inequality is very serious"
gen ineq_vs=inequality_problem==5 if inequality_problem~=. 

* The high income people are deserving of their income
gen deserving_yes=deserving==3 if deserving~=. 
label var deserving "High income people are deserving of their income"

* Trust the government binary variable
gen trust_gov_yes=trust_government>2 if trust_government~=. 
label var trust_gov_yes "Yes, trust the government"

* Goal of taxes is to redistribute income
gen goal_redistr=taxes_goal==3 if taxes_goal~=. 
label var goal_redistr "Role of taxes is to redistribute"

**** We separate our two petition questions (they were about higher taxes in first few rounds, estate tax later)
gen petition_taxes=petition if round<7
gen petition_estate=petition if round>6
gen petition_high_tax=petition_taxes==1 if petition_taxes~=.
gen petition_high_estate=petition_estate==1 if petition_estate~=.
gen petition_high=petition==1 if petition~=.
label var petition_high "Said would petition for either higher inc or estate taxes (pooled)"
label var petition_high_tax "Said would petition for higher inc taxes (early rounds only)"
label var petition_high_estate "Said would petition for higher estate taxes (later rounds only)"

* Are you satisfied with your own income?
replace satisfied = 5-satisfied 
*increasing satisfied means more satisfied.

**** Knowledge questions outcomes reported in Appendix
gen toptax1950_correct = (toptaxes1950 == 1) if toptaxes1950 != . 
gen growth_correct = (growth == 3) if growth != . 

** World view: do people mostly think income is the result of own effort?
gen fairworld = (worldbelief == 1) if worldbelief !=. 

** Tax differential between the top 1% and the Bottom 50% chosen tax rate; 
gen tax_diff = taxrate1_1 - taxrate4_1

* Correct answers to questions on inequality slider pages -- tests people's understanding of the info shown.

gen q1_corr = (t1_1 == "99" | t1_1 == "0.99" | t1_1 == "99%" | t1_1 == "99.00%" ) if t1_1 != "" 
tab q1_corr
gen q2_corr = (t1_2 == "90" | t1_2 == "0.9" | t1_2 == "90%" | t1_2 == "90.00%" ) if t1_2 != ""
tab q2_corr
gen q3_corr = (t1_3 == "50" | t1_3 == "0.5" | t1_3 == "50%") if t1_3 != ""
tab q3_corr

gen q4_corr = (t2_1 == "281000" | t2_1 == "281,000" | t2_1 == "$281,000" | t2_1 == "27" | t2_1 == "27 less" | t2_1 == "27% less") if t2_1 != "" & t2_1 != "."
tab q4_corr
gen q5_corr = (t2_2 == "117000" | t2_2 == "117,000" | t2_2 == "$117,000" | t2_2 == "117,00" | t2_2 == "117000.00" | t2_2 =="8" | t2_2 == "8% more") if t2_2 != "" & t2_2 != "0"
tab q5_corr
gen q6_corr = (t2_3 == "45700" | t2_3 == "45,700" | t2_3 == "$45,700" | t2_3 == "45,700.00" | t2_3 == "45700.00" | t2_3 == "35" | t2_3 == "35% more") if t2_3 != ""
tab q6_corr


local controls "obama08 age policyview hhincome educ male black hisp native unemp nilf student rrr* eee* married fulltime "  

# delimit ; 

******************************************************************************************
** Do some summary stats for attrition; 
******************************************************************************************;

sort round; 
by round: egen totaltaken = count(treat); 
by round: egen totalcompleted = total(finished); 
gen fractioncomplete = totalcompleted/totaltaken; 

summarize fractioncomplete if round == 6; 
summarize fractioncomplete if round == 7; 
summarize fractioncomplete if round > 7 & round < 8 ; 
summarize fractioncomplete if round == 8; 

drop totaltaken totalcompleted fractioncomplete; 

egen totaltaken = count(treat); 
egen totalcompleted = total(finished); 
gen fractioncomplete = totalcompleted/totaltaken; 

summarize fractioncomplete; 

** Overall fraction of control group that finished; 
drop totaltaken totalcompleted fractioncomplete; 
sort treat; 
egen totaltaken = count(treat), by(treat); 
egen totalcompleted = total(finished), by(treat); 
gen fractioncomplete = totalcompleted/totaltaken; 

summarize fractioncomplete if treat == 0;
summarize fractioncomplete if treat == 1 ;

** Overall fraction of control group that finished; 
drop totaltaken totalcompleted fractioncomplete; 
sort round treat; 
egen totaltaken = count(treat), by(round treat); 
egen totalcompleted = total(finished), by(round treat); 
gen fractioncomplete = totalcompleted/totaltaken; 

summarize fractioncomplete if round == 6 & treat == 0; 
summarize fractioncomplete if round == 7 & treat == 0; 
summarize fractioncomplete if round > 7 & round < 8 & treat == 0; 
summarize fractioncomplete if round == 8 & treat == 0; 

summarize fractioncomplete if round == 6 & treat == 1; 
summarize fractioncomplete if round == 7 & treat == 1; 
summarize fractioncomplete if round > 7 & round < 8 & treat == 1; 
summarize fractioncomplete if round == 8 & treat == 1; 

drop totaltaken totalcompleted fractioncomplete; 
 


#delimit ;

******************************************************************************************
**** Attrition
******************************************************************************************;

eststo clear ;

local j 0 ;
foreach var of varlist obama08 age policyview hhincome married educ male black hisp native fulltime unemp nilf student { ;
local ++j ;
gen `var'_treat = `var'*treat;
eststo `var': reg finished treat `var'_treat `var' rrr* ;
local varlab: variable label `var' ; 
local estno "est`j'" ;
local relabel `"`relabel' `estno' "`varlab'""' ;
local beta=_b[`var'] ;
estadd scalar beta=`beta' ;
local betatreat = _b[`var'_treat]; 
estadd scalar betatreat=`betatreat' ;
local obsvector=`"`obsvector' "`obs'""' ;
local titlevector=`"`titlevector' "`var'""' ;

di `"`titlevector'" ;

****Now, calculate p-values ;
local pval=2*ttail(e(df_r), abs(_b[`var']/_se[`var'])) ;
estadd scalar pvalue =  `pval' ;

local pvaltreat=2*ttail(e(df_r), abs(_b[`var'_treat]/_se[`var'_treat])) ;
estadd scalar pvaluetreat =  `pvaltreat' ;

drop `var'_treat; 

} ;

esttab , cells(none) stats(beta pvalue betatreat pvaluetreat) label mtitles(`"titlevector"') ;
matrix list r(stats) ;

***** ;
matrix S = r(stats) ;
eststo clear ;
local rnames : rownames S ;
di `"`rnames'"' ;
local models : colnames S ;
local models : list uniq models ;
local i 0 ;
foreach name of local rnames { ;
    local ++i ;
    local j 0 ;
    capture matrix drop b btreat ;
    foreach model of local models { ;
        local ++j ;
        di S[`i', `j'] ;
        matrix tmp = S[`i', `j'] ;
        if tmp[1,1]<. { ;
            matrix colnames tmp = `model' ;
            matrix b = nullmat(b), tmp ;
            matrix btreat = nullmat(btreat), tmp ;
            matrix tmp[1,1] = S[`i', 3*`j'-1] ;
            
        } ;
    } ;
    ereturn post b ;
    ereturn post btreat ;  
    * quietly estadd matrix se ;
    eststo `name' ;
} ;
****RELABEL VARS ;

foreach var of varlist black male education native age student married { ;
local temp=proper("`var'") ;
label var `var' "`temp'" ;
} ;
label var obama08 "Voted for Obama in 2008" ;
label var policyview "Liberal policy view" ;
label var hhincome "Household income" ;
label var nilf "Not in labor force" ;
label var unemp "Unemployed" ;
label var hisp "Hispanic" ;
label var fulltime "Employed full time" ;

esttab using selection_old.tex, replace fragment booktabs varwidth(20) wrap cells(b)
mlabels("Coeff" "P-val" "Interaction with Treat" "P-val", nonum lhs("Variable")) label noisily noobs nonumbers nogaps collabels(none) ;

******** Is there differential attrition? Complete Table for the Appendix;

eststo clear ;

local j 0 ;
foreach var of varlist obama08 age policyview hhincome married educ male black hisp native fulltime unemp nilf student treat { ;
local ++j ;
eststo `var': reg finished `var' rrr* ;
local varlab: variable label `var' ; 
local estno "est`j'" ;
local relabel `"`relabel' `estno' "`varlab'""' ;
local beta=_b[`var'] ;
estadd scalar beta=`beta' ;
local obsvector=`"`obsvector' "`obs'""' ;
local titlevector=`"`titlevector' "`var'""' ;

di `"`titlevector'" ;

****Now, calculate p-values ;
local pval=2*ttail(e(df_r), abs(_b[`var']/_se[`var'])) ;
estadd scalar pvalue =  `pval' ;
} ;

esttab , cells(none) stats(beta pvalue) label mtitles(`"titlevector"') ;
matrix list r(stats) ;

***** ;
matrix S = r(stats) ;
eststo clear ;
local rnames : rownames S ;
di `"`rnames'"' ;
local models : colnames S ;
local models : list uniq models ;
local i 0 ;
foreach name of local rnames { ;
    local ++i ;
    local j 0 ;
    capture matrix drop b ;
    foreach model of local models { ;
        local ++j ;
        di S[`i', `j'] ;
        matrix tmp = S[`i', `j'] ;
        if tmp[1,1]<. { ;
            matrix colnames tmp = `model' ;
            matrix b = nullmat(b), tmp ;
            matrix tmp[1,1] = S[`i', 3*`j'-1] ;
            
        } ;
    } ;
    ereturn post b ;
    eststo `name' ;
} ;

foreach var of varlist black male education native age student married { ;
local temp=proper("`var'") ;
label var `var' "`temp'" ;
} ;
label var obama08 "Voted for Obama in 2008" ;
label var policyview "Liberal policy view" ;
label var hhincome "Household income" ;
label var nilf "Not in labor force" ;
label var unemp "Unemployed" ;
label var hisp "Hispanic" ;
label var fulltime "Employed full time" ;
label var treat "Treatment Group"; 

esttab using attrition_old.tex, replace fragment booktabs varwidth(20) wrap cells(b(fmt(3)))
mlabels("Coeff" "P-val", nonum lhs("Variable")) label noisily noobs nonumbers nogaps collabels(none) ;


******************************************************************************************
**** Check for Randomization Balance; 
******************************************************************************************;

eststo clear ;

local j 0 ;
foreach var of varlist obama08 age policyview hhincome married educ male black hisp native fulltime unemp nilf student { ;
local ++j ;
eststo `var': reg treat `var' rrr* if taxrate1_1~=.   ;
local varlab: variable label `var' ; 
local estno "est`j'" ;
local relabel `"`relabel' `estno' "`varlab'""' ;
local beta=_b[`var'] ;
estadd scalar beta=`beta' ;
local obsvector=`"`obsvector' "`obs'""' ;
local titlevector=`"`titlevector' "`var'""' ;

di `"`titlevector'" ;

****Now, calculate p-value ;
local pval=2*ttail(e(df_r), abs(_b[`var']/_se[`var'])) ;
estadd scalar pvalue =  `pval' ;
*estadd scalar beta = _b[`var'] ;


} ;

esttab , cells(none) stats(beta pvalue) label mtitles(`"titlevector"') ;
matrix list r(stats) ;

***** ;
matrix C = r(stats) ;
eststo clear ;
local rnames : rownames C ;
di `"`rnames'"' ;
local models : colnames C ;
local models : list uniq models ;
local i 0 ;
foreach name of local rnames { ;
    local ++i ;
    local j 0 ;
    capture matrix drop b ;
    * capture matrix drop se ;
    foreach model of local models { ;
        local ++j ;
        di C[`i', `j'] ;
        matrix tmp = C[`i', `j'] ;
        if tmp[1,1]<. { ;
            matrix colnames tmp = `model' ;
            matrix b = nullmat(b), tmp ;
            matrix tmp[1,1] = C[`i', 3*`j'-1] ;
            * matrix se = nullmat(se), tmp ;
        } ;
    } ;
    ereturn post b ;
    * quietly estadd matrix se ;
    eststo `name' ;
} ;
****RELABEL VARS ;

foreach var of varlist black male education native age student married { ;
local temp=proper("`var'") ;
label var `var' "`temp'" ;
} ;
label var obama08 "Voted for Obama in 2008" ;
label var policyview "Liberal policy view" ;
label var hhincome "Household income" ;
label var nilf "Not in labor force" ;
label var unemp "Unemployed" ;
label var hisp "Hispanic" ;
label var fulltime "Employed full time" ;

esttab using randomization_old.tex, replace fragment booktabs varwidth(30) wrap cells(b(fmt(3)))
mlabels("Coefficient" "P-value", nonum lhs("Variable")) label noisily noobs nonumbers nogaps collabels(none) ;

** Full test on treatment status for all variables jointly;

eststo clear; 
reg treat obama08 age policyview hhincome married educ male black hisp native fulltime unemp nilf student rrr* if taxrate1_1~=.; 


******************************************************************************************
**** Bounding Exercise to control for Selective Attrition for Appendix; 
******************************************************************************************;

gen missing=0 ;
foreach var of varlist `controls' state { ;
replace missing=1 if `var'==. ;
} ;


foreach var of varlist ineq_vs taxrate1_1 inc_mill_yes inc_estate_yes trust_gov_yes { ;
gen `var'_temp = `var'; 
}; 

label var treat "Treated"; 

eststo clear ;
foreach var of varlist ineq_vs_temp inc_mill_yes_temp inc_estate_yes_temp trust_gov_yes_temp { ;
summ `var' if conservative == 1; 
local meancons = r(mean);   
replace `var' = `meancons' if finished == 0; 
eststo: reg `var' rrr* treat; 
qui sum `var' if treat==0 ;
estadd scalar cmean=`r(mean)' ;
summ `var' if liberal == 1; 
local meanlib = r(mean);   
replace `var' = `meanlib' if finished == 0; 
eststo: reg `var' rrr* treat;
qui sum `var' if treat==0 ;
estadd scalar cmean=`r(mean)' ;
} ;

esttab using appendix_avg_bounds.tex, replace fragment booktabs keep(treat) label 
mgroups("Ineq. v. serious" "Increase Mill. Tax" "Increase Estate Tax" "Trust Gov", pattern(1 0 1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
star(* .1 ** .05 *** .01) brackets se mtitles("C" "L" "C" "L" "C" "L" "C" "L") stats(cmean N, label("Control mean" "Obs.")) ;

eststo clear; 

drop missing; 

************************************************;
*************SUMMARY TABLES ;
************************************************;

eststo clear; 

label var asian "Asian" ;
label var college "Has college degree" ;
label var white "White" ;
label var policyview3 "Pol. views, 1 (Cons) to 3 (Lib)" ;
label var taxrate1_1 "Top Tax Rate"; 
label var inc_mill_yes "Increase Millionaire Tax"; 
label var inc_estate_yes "Increase Estate Tax"; 
label var inc_mw "Increase min wage"; 
label var support_food "Support food stamps";  
label var support_eitc "Support EITC";  
label var trust_gov_yes "Trust Govt"; 
label var purpose "Scope of Govt is broad";
label var petition_high_est "Send petition for high estate tax"; 
label var democrat12 "Plan to vote democrat 2012"; 
label var ineq_inc_yes "Inequality has increased";
label var ineq_vs "Inequality is a very serious problem"; 

eststo: estpost sum male age white black hisp asian married college unemp nilf obama08 ineq_inc_yes ineq_vs  taxrate1_1 inc_mill_yes inc_estate_yes 
inc_mw support_food support_eitc
trust_gov_yes purpose
petition_high_tax petition_high_est democrat12
if taxrate1_1~=. & treat == 0 & liberal == 1 ;

eststo: estpost sum male age white black hisp asian married college unemp nilf obama08 ineq_inc_yes ineq_vs  taxrate1_1 inc_mill_yes inc_estate_yes 
inc_mw support_eitc support_food support_eitc
trust_gov_yes purpose 
petition_high_tax petition_high_est democrat12
if taxrate1_1~=. & treat == 0 & conservative == 1 ;

eststo: estpost sum male age white black hisp asian married college unemp nilf obama08 ineq_inc_yes ineq_vs taxrate1_1 inc_mill_yes inc_estate_yes 
inc_mw support_eitc support_food support_eitc
trust_gov_yes purpose
petition_high_tax petition_high_est democrat12 
if taxrate1_1~=. & treat == 0  ;


esttab using summary_controlgp_old.tex, replace booktabs fragment cells(mean(fmt(3))) mtitles("Liberals" "Conservatives" "All")
label stats(N, fmt(0) label("Observations")) nogaps collabels(none) wrap varwidth(30)  ;

* stats(N, fmt(0) label("Observations")) ;

esttab, cells(mean) ;


************************************************;
*** Comparing the mTurk Sample to CBS; 
************************************************;

drop if age<18 | age==. ;
drop if gender==. ;
drop if ethnic==. ;

****Generate age buckets ;
gen age3=1 if age>17 & age<28 ;
replace age3=2 if age>27 & age<41 ;
replace age3=3 if age>40 & age~=. ;

gen age2=age<40 ;


eststo clear ;

eststo: estpost sum male age white black hisp asian married college unemp nilf  obama08 policyview3 if taxrate1_1~=.  ;

preserve ;

* Read in 2011 polling data so we can use these data to create weights ;

use cbs_2011, clear ;
ren AGE age ;
ren WGHT wgt_cbs ;
ren RACE race ;
gen hisp=HISP==1 ;
gen college=EDUC>3 if EDUC<6 ;
gen policyview3=4-PPHL ;
gen married=MAR==1  ;
gen unemp=Q77==2 ;
gen nilf = Q77==3 | Q77==4 ;

gen age3=1 if age>17 & age<28 ;
replace age3=2 if age>27 & age<41 ;
replace age3=3 if age>40 & age~=. ;

gen age2=age<40 ;

***Create ethnic categories to match mTurk survey ;

**white NH ;
gen ethnic=1 if race==1 & hisp==0 & race<9 ;
***black NH ;
replace ethnic=2 if race==2 & hisp==0  ;
***Hisp ;
replace ethnic=3 if hisp==1 ; 
****Asian NH ;
replace ethnic=4 if race==3 & hisp==0  ;
****Other ;
replace ethnic=5 if race==4 & hisp==0;

gen white=ethnic==1 if ethnic~=. ;

gen male=SEX==1 ;

***Obama 08 ;
gen obama08=VT08==1 if VT08<4 ;

***Drop anyone who has missing value for the groups we are weigting on ;
drop if obama08==. | ethnic==. | age3==. | college==. ;

****In text, we mention what unweighted numbers look like ;

sum age college hisp unemp nilf male ;
sum age college hisp unemp nilf male [aw=wgt_cbs] ;

gen black=ethnic==2 if ethnic~=. ;
gen asian=ethnic==4 if ethnic~=. ;

sum male age black hisp asian [aw=wgt_cbs] ;

eststo: estpost sum male age white black hisp asian married college unemp nilf obama08 policyview3  [aw=wgt_cbs] ;

restore ;
* drop _merge ;

drop if taxrate1_1==. ;

label var asian "Asian" ;
label var college "Has college degree" ;
label var white "White" ;
label var policyview3 "Pol. views, 1 (Cons) to 3 (Lib)" ;

esttab using weighting.tex, replace booktabs fragment cells(mean(fmt(a3))) mtitles("mTurk (unwgted)" "CBS" )
stats(N, label("Observations")) label nogaps collabels(none) wrap varwidth(24)  ;

esttab, cells(mean) ;

** Here we use a ready provided table from Ray Fisman with summary stats from the ALP sample; 
** They are in the file alp_nowgt.ster; 

estimates use alp_nowgt.ster ;

eststo ;

esttab using alp_compare.tex, replace booktabs fragment mtitles("mTurk (Ombnibus
surveys)" "CBS (weighted)" "American Life Panel")
cells(mean(fmt(a3)) sd(par(( )))) collabels(none) varwidth(26) wrap label; 


*************************************************************** ;
****************** MAIN TABLES FOR THE PAPER ; 
****************************************************************;


gen missing=0 ;
foreach var of varlist `controls' state { ;
replace missing=1 if `var'==. ;
} ;


label var treat "Treated" ;

** FIRST STAGE EFFECTS ;

eststo clear ;

foreach var of varlist ineq_vs ineq_inc_yes deserving_yes { ;
eststo: reg `var' rrr* treat if missing==0 ;
estadd local controls "No" ;
qui sum `var' if treat==0  ;
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat==0 & liberal ==  1; 
local meanlib = `r(mean)'; 
qui sum `var' if treat==0 & conservative ==  1; 
local meancons = `r(mean)'; 
local lib_cons = `meanlib'-`meancons';
estadd scalar beta_scaled = abs(_b[treat]/`lib_cons'); 
eststo: areg `var' treat `controls' if missing==0, abs(state) ;
estadd local controls "Yes" ;
qui sum `var' if treat==0 ;
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat==0 & liberal ==  1; 
local meanlib = `r(mean)'; 
qui sum `var' if treat==0 & conservative ==  1; 
local meancons = `r(mean)'; 
local lib_cons = abs(`meanlib'-`meancons');  
estadd scalar beta_scaled = abs(_b[treat]/`lib_cons'); 
} ;

esttab using first_stage_nowt_scaled_old.tex, replace fragment booktabs keep(treat) label 
mgroups("Ineq. v. serious" "Ineq. increased" "Rich deserving", pattern(1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
star(* .1 ** .05 *** .01) brackets se nomtitles stats(cmean beta_scaled  controls N, label("Control mean" "Scaled Effect" "Covariates?" "Obs.")) ;


eststo clear; 

foreach var of varlist taxrate1_1 inc_mill_yes inc_estate_yes petition_high_est inc_mw trust_gov_yes 
purpose_government democrat12 { ;
eststo: areg `var' treat `controls' if missing==0 , abs(state) ;
qui sum `var' if treat==0  ;
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat==0 & liberal ==  1; 
local meanlib = `r(mean)'; 
qui sum `var' if treat==0 & conservative ==  1; 
local meancons = `r(mean)'; 
local lib_cons = abs(`meanlib'-`meancons');  
estadd scalar beta_scaled = abs(_b[treat]/`lib_cons'); 

}; 

esttab using outcomes_old.tex, replace fragment booktabs keep(treat) label 
star(* .1 ** .05 *** .01) brackets se nomtitles stats(cmean beta_scaled N, label("Control mean" "Scaled Effect" "Obs.")) ;


******************************************************************************************
***** APPENDIX TABLES 
*****************************************************************************************;

eststo clear; 
foreach var of varlist ineq_vs ineq_inc_yes deserving_yes taxrate1_1 inc_mill_yes inc_estate_yes petition_high_est inc_mw support_food  
support_eitc trust_gov_yes 
purpose_government { ;
eststo: areg `var' treat `controls' if missing==0 , abs(state) ;
qui sum `var' if treat==0  ;
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat==0 & liberal ==  1; 
local meanlib = `r(mean)'; 
qui sum `var' if treat==0 & conservative ==  1; 
local meancons = `r(mean)'; 
local lib_cons = abs(`meanlib'-`meancons');  
estadd scalar beta_scaled = abs(_b[treat]/`lib_cons'); 

}; 

esttab using omnibus1.tex, replace fragment booktabs keep(treat) label 
mgroups("Ineq vs." "Ineq. inc." "Deserving" "Top tax" "Mill. tax" "Estate tax" "Petition" "Min. wage" "Food stamps" "EITC" "Trust" "Scope" , pattern(1 1 1 1 1 1 1 1 1 1 1 1) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
star(* .1 ** .05 *** .01) brackets se nomtitles stats(cmean beta_scaled N, label("Control mean" "Scaled Effect" "Obs.")) ;

eststo clear; 
foreach var of varlist democrat12 goal_redistr growth_correct toptax1950_correct satisfied charity_money charity_money_past charity_time charity_time_past { ;
eststo: areg `var' treat `controls' if missing==0 , abs(state) ;
qui sum `var' if treat==0  ;
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat==0 & liberal ==  1; 
local meanlib = `r(mean)'; 
qui sum `var' if treat==0 & conservative ==  1; 
local meancons = `r(mean)'; 
local lib_cons = abs(`meanlib'-`meancons');  
estadd scalar beta_scaled = abs(_b[treat]/`lib_cons'); 

}; 

esttab using omnibus2.tex, replace fragment booktabs keep(treat) label 
mgroups("Dem. 2012" "Taxes redistr." "Growth" "Tax 1950" "Satisfied" "Money charity" "Money given" "Time charity" "Time given", pattern(1 1 1 1 1 1 1 1 1) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
star(* .1 ** .05 *** .01) brackets se nomtitles stats(cmean beta_scaled N, label("Control mean" "Scaled Effect" "Obs.")) ;

eststo clear; 

label var q1_corr "Pct of households earn less than 386,000";
label var q2_corr "Pct of households earn less than 108,000";
label var q3_corr "Pct of households earn less than 33,800";
label var q4_corr "Household now making 386,000 would be making...";
label var q5_corr "Household now making 108,000 would be making...";
label var q6_corr "Household now making 33,800 would be making...";

eststo: estpost sum q1_corr q2_corr q3_corr q4_corr q5_corr q6_corr;

esttab using omnibus3.tex, replace booktabs fragment cells(mean(fmt(3))) mtitles("Percent that answered correctly")
label stats(N, fmt(0) label("Observations")) nogaps collabels(none) wrap varwidth(30)  ;

esttab, cells(mean) ;

eststo clear; 
foreach var of varlist fairworld taxrate1_1 taxrate2_1 taxrate3_1 taxrate4_1 tax_diff { ;
eststo: areg `var' treat `controls' if missing==0 , abs(state) ;
qui sum `var' if treat==0  ;
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat==0 & liberal ==  1; 
local meanlib = `r(mean)'; 
qui sum `var' if treat==0 & conservative ==  1; 
local meancons = `r(mean)'; 
local lib_cons = abs(`meanlib'-`meancons');  
estadd scalar beta_scaled = abs(_b[treat]/`lib_cons'); 

}; 

esttab using omnibus4.tex, replace fragment booktabs keep(treat) label 
mgroups("Income due to effort" "Tax on top 1\%" "Tax on next 9\%" "Tax on next 40\%" "Tax on Bottom 50\%" "Top 1\% tax - Bottom 50\% tax", pattern(1 1 1 1 1 1) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
star(* .1 ** .05 *** .01) brackets se nomtitles stats(cmean beta_scaled N, label("Control mean" "Scaled Effect" "Obs.")) ;


*************************************************************************************************************************************
**** Attrition Study: Looking at low vs high attrition rounds, Appendix Tables 
*************************************************************************************************************************************

foreach var of varlist obama08 age policyview hhincome married educ male black hisp native fulltime unemp nilf student {
gen treat_`var' = treat*`var'
} 

local attrition2 = "obama08 age policyview hhincome married educ male black hisp native fulltime unemp nilf student 
treat_obama08 treat_age treat_policyview treat_hhincome treat_married treat_educ treat_male treat_black treat_hisp treat_native treat_fulltime treat_unemp treat_nilf treat_student" 

reg finished `attrition2' 
predict propensity_finish, xb 

summ propensity_finish, detail 
local above_median `r(p50)'
gen propfinish = (propensity_finish >= `above_median') if propensity_finish ! = .

foreach var of varlist obama08 age policyview hhincome married educ male black hisp native fulltime unemp nilf student {
drop treat_`var'
}; 

gen propfinish = . ; 
replace propfinish = 1 if round == 4 | round == 5 | round == 8; 
replace propfinish = 0 if round == 6 | round == 7 | round == 7.1; 

count if propfinish == 1;
tab finished if treat == 1 & propfinish == 1; 
tab finished if treat == 0 & propfinish == 1; 
count if propfinish == 0; 
tab finished if treat == 1 & propfinish == 0; 
tab finished if treat == 0 & propfinish == 0; 

* Generate a binary variable based on the propensity to finish the survey, with propensity above and below the median respectively

summ propensity_finish, detail
local above_median `r(p50)'
gen propfinish = (propensity_finish >= `above_median') if propensity_finish ! = . ; 
  
label var treat "Treated" ;

eststo clear ;
foreach var of varlist ineq_vs ineq_inc_yes deserving_yes taxrate1_1 inc_mill_yes inc_estate_yes { ;
eststo: areg `var' treat `controls' if missing==0 & propfinish == 1, abs(state) ;
estadd local grouppropensity "Low" ;
qui sum `var' if treat==0 & propfinish  == 1;
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat==0 &  propfinish == 1 & liberal ==  1; 
local meanlib = `r(mean)'; 
qui sum `var' if treat==0 & conservative ==  1 & propfinish  == 1; 
local meancons = `r(mean)'; 
local lib_cons = `meanlib'-`meancons';
estadd scalar beta_scaled = abs(_b[treat]/`lib_cons'); 
eststo: areg `var' treat `controls' if missing==0 & propfinish  == 0, abs(state) ;
estadd local grouppropensity "High" ;
qui sum `var' if treat==0 & propfinish == 0 ;
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat==0 & liberal ==  1 & propfinish == 0; 
local meanlib = `r(mean)'; 
qui sum `var' if treat==0 & conservative ==  1 & propfinish == 0; 
local meancons = `r(mean)'; 
local lib_cons = abs(`meanlib'-`meancons');  
estadd scalar beta_scaled = abs(_b[treat]/`lib_cons'); 
} ;

esttab using attrition_prop1.tex, replace fragment booktabs keep(treat) label 
mgroups("Ineq. v. serious" "Ineq. increased" "Rich deserving" "Top tax rate" "Increase Mill. Tax" "Estate tax", pattern(1 0 1 0 1 0 1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
star(* .1 ** .05 *** .01) brackets se nomtitles stats(cmean beta_scaled grouppropensity N, label("Control mean" "Scaled Effect" "Differential attrition?" "Obs.")) ;

eststo clear ;
foreach var of varlist inc_mw support_eitc support_food trust_gov_yes purpose { ;
eststo: areg `var' treat `controls' if missing==0 & propfinish == 1, abs(state) ;
estadd local grouppropensity "Low" ;
qui sum `var' if treat==0 & propfinish  == 1;
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat==0 &  propfinish == 1 & liberal ==  1; 
local meanlib = `r(mean)'; 
qui sum `var' if treat==0 & conservative ==  1 & propfinish  == 1; 
local meancons = `r(mean)'; 
local lib_cons = `meanlib'-`meancons';
estadd scalar beta_scaled = abs(_b[treat]/`lib_cons'); 
eststo: areg `var' treat `controls' if missing==0 & propfinish  == 0, abs(state) ;
estadd local grouppropensity "High" ;
qui sum `var' if treat==0 & propfinish == 0 ;
estadd scalar cmean=`r(mean)' ;
qui sum `var' if treat==0 & liberal ==  1 & propfinish == 0; 
local meanlib = `r(mean)'; 
qui sum `var' if treat==0 & conservative ==  1 & propfinish == 0; 
local meancons = `r(mean)'; 
local lib_cons = abs(`meanlib'-`meancons');  
estadd scalar beta_scaled = abs(_b[treat]/`lib_cons'); 
} ;

esttab using attrition_prop2.tex, replace fragment booktabs keep(treat) label 
mgroups("Min. wage" "EITC" "Food stamps" "Trust gov." "Scope", pattern(1 0 1 0 1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
star(* .1 ** .05 *** .01) brackets se nomtitles stats(cmean beta_scaled grouppropensity N, label("Control mean" "Scaled Effect" "Differential attrition?" "Obs.")) ;




exit; 

cap log close; 
